@@ -484,8 +484,6 @@ class TimeResampler(Resampler):
         )
 
     def _init_properties(self, group: T_Group) -> None:
-        from xarray import CFTimeIndex
-
         group_as_index = safe_cast_to_index(group)
         offset = self.offset
 
@@ -494,8 +492,6 @@ class TimeResampler(Resampler):
             raise ValueError("Index must be monotonic for resampling")
 
         if isinstance(group_as_index, CFTimeIndex):
-            from xarray.core.resample_cftime import CFTimeGrouper
-
             self.index_grouper = CFTimeGrouper(
                 freq=self.freq,
                 closed=self.closed,
@@ -553,7 +549,7 @@ class TimeResampler(Resampler):
         full_index, first_items, codes_ = self._get_index_and_items()
         sbins = first_items.values.astype(np.int64)
         group_indices: GroupIndices = tuple(
-            [slice(i, j) for i, j in pairwise(sbins)] + [slice(sbins[-1], None)]
+            list(itertools.starmap(slice, pairwise(sbins))) + [slice(sbins[-1], None)]
         )
 
         unique_coord = Variable(
@@ -621,10 +617,10 @@ def season_to_month_tuple(seasons: Sequence[str]) -> tuple[tuple[int, ...], ...]
     ((12, 1, 2, 3), (9, 10, 11, 12))
     """
     initials = "JFMAMJJASOND"
-    starts = dict(
-        ("".join(s), i + 1)
+    starts = {
+        "".join(s): i + 1
         for s, i in zip(sliding_window(2, initials + "J"), range(12), strict=True)
-    )
+    }
     result: list[tuple[int, ...]] = []
     for i, season in enumerate(seasons):
         if len(season) == 1:
@@ -695,8 +691,7 @@ def find_independent_seasons(seasons: Sequence[str]) -> Sequence[SeasonsGroup]:
     >>> find_independent_seasons(
     ...     ["DJF", "FMA", "AMJ", "JJA", "ASO", "OND"]
     ... )  # doctest: +NORMALIZE_WHITESPACE
-    [SeasonsGroup(seasons=('DJF', 'AMJ', 'ASO'), inds=((12, 1, 2), (4, 5, 6), (8, 9, 10)), codes=[0, 2, 4]),
-    SeasonsGroup(seasons=('FMA', 'JJA', 'OND'), inds=((2, 3, 4), (6, 7, 8), (10, 11, 12)), codes=[1, 3, 5])]
+    [SeasonsGroup(seasons=('DJF', 'AMJ', 'ASO'), inds=((12, 1, 2), (4, 5, 6), (8, 9, 10)), codes=[0, 2, 4]), SeasonsGroup(seasons=('FMA', 'JJA', 'OND'), inds=((2, 3, 4), (6, 7, 8), (10, 11, 12)), codes=[1, 3, 5])]
 
     >>> find_independent_seasons(["DJF", "MAM", "JJA", "SON"])
     [SeasonsGroup(seasons=('DJF', 'MAM', 'JJA', 'SON'), inds=((12, 1, 2), (3, 4, 5), (6, 7, 8), (9, 10, 11)), codes=[0, 1, 2, 3])]
@@ -705,25 +700,23 @@ def find_independent_seasons(seasons: Sequence[str]) -> Sequence[SeasonsGroup]:
     grouped = defaultdict(list)
     codes = defaultdict(list)
     seen: set[tuple[int, ...]] = set()
-    idx = 0
     # This is quadratic, but the number of seasons is at most 12
     for i, current in enumerate(season_inds):
         # Start with a group
         if current not in seen:
-            grouped[idx].append(current)
-            codes[idx].append(i)
+            grouped[i].append(current)
+            codes[i].append(i)
             seen.add(current)
 
         # Loop through remaining groups, and look for overlaps
         for j, second in enumerate(season_inds[i:]):
-            if not (set(chain(*grouped[idx])) & set(second)) and second not in seen:
-                grouped[idx].append(second)
-                codes[idx].append(j + i)
+            if not (set(chain(*grouped[i])) & set(second)) and second not in seen:
+                grouped[i].append(second)
+                codes[i].append(j + i)
                 seen.add(second)
         if len(seen) == len(seasons):
             break
-        # found all non-overlapping groups for this row, increment and start over
-        idx += 1
+        # found all non-overlapping groups for this row start over
 
     grouped_ints = tuple(tuple(idx) for idx in grouped.values() if idx)
     return [
